@@ -3,15 +3,19 @@
 # TODO: New (simpler) complementary function for calculating stutters.
 #   Pros: possibility to get proportion with stutter/no stutter
 #   Cons: difficult to include microvariant stutters.
-#   1) Get true alleles from reference, 2) Construct stutter range from these, 
+#   1) Get true alleles from reference,
+#   2) Construct stutter range from these, 
 #   3) Mask for interference according to 0/1/2 system,
 #   4) Match to alleles. No match scores as no stutter,
-#   5) Match/pick peak heights, 6) calculate ratios.
-# TODO: option to filter peaks below (LOD) or above a treshold. (e.g. <50 or >5000 rfu)
-# TODO: Detect pull-ups and other noise within stutter range.
+#   5) Match/pick peak heights,
+#   6) calculate ratios.
+# TODO: option to filter peaks below (LOD) or above a treshold
+#  (e.g. <50 or >5000 rfu)?
+# TODO: Detect pull-ups and other noise within stutter range?
 
 ################################################################################
 # CHANGE LOG
+# 30.11.2013: 'warning' changed to 'message' when data is converted.
 # 01.07.2013: Added "Sample.Name" in result.
 # 01.07.2013: Fixed "NAs introduced by coercion".
 # 25.06.2013: Fixed bug for 'interference = 1'.
@@ -21,9 +25,6 @@
 # 30.05.2013: New parameters 'replaceVal' and 'byVal' to fix 'false' stutters.
 # 30.05.2013: 'Type' rounded to 1 digit (avoid floating point 'bug' when ==)
 # 11.04.2013: Added some more data controls.
-# <11.04.2013: Fix bug mixed numeric/character, slim data required.
-# <11.04.2013: Roxygenized and changed name from stutterStatSlim to calculateStutter.
-# <11.04.2013: New function StutterStatSlim works with slimmed data.
 
 #' @title Calculate stutter
 #'
@@ -31,23 +32,32 @@
 #' \code{calculateStutter} calculates statistics for stutters.
 #'
 #' @details
-#' Calculates stutter ratios based on the 'reference' data set.
-#' NB! Off-ladder alleles ('OL') is NOT included in the analysis.
-#' NB! Labelled pull-ups or artefacts within stutter range
-#'  IS included in the analysis. 
+#' Calculates stutter ratios based on the 'reference' data set
+#' and a defined analysis range aroung the true allele.
 #' 
-#' @param data data frame with genotype data in 'slim' format.
+#' NB! Off-ladder alleles ('OL') is NOT included in the analysis.
+#' NB! Labelled pull-ups or artefacts within stutter range IS included
+#'  in the analysis. 
+#' 
+#' There are three levels of allowed overlap (interference).
+#' 0 = no interference (default): calculate the ratio for a stutter only if
+#'  there are no overlap between the stutter or its allele with the analysis
+#'  range of another allele.
+#' 1 = stutter-stutter interference: calculate the ratio for a stutter even
+#'  if the stutter or its allele overlap with a stutter within the analysis
+#'  range of another allele.
+#' 2 = stutter-allele interference: calculate the ratio for a stutter even if
+#'  the stutter and its allele overlap with the analysis range of another allele.
+#' 
+#' @param data data frame with genotype data.
 #' Requires columns 'Sample.Name', 'Marker', 'Allele', 'Height'.
-#' @param ref data frame in 'slim' format with the known profiles.
+#' @param ref data frame with the known profiles.
 #' Requires columns 'Sample.Name', 'Marker', 'Allele'.
 #' @param back integer for the maximal number of backward stutters
 #'  (max size difference 2 = n-2 repeats).
 #' @param forward integer for the maximal number of forward stutters
 #'  (max size difference 1 = n+1 repeats).
-#' @param interference integer specifying accepted level of interference between peaks.
-#'  0 = no overlap between stutters and alleles is allowed.
-#'  1 = stutter-stutter interference is allowed.
-#'  2 = stutter-allele interference is allowed.
+#' @param interference integer specifying accepted level of allowed overlap.
 #' @param replaceVal numeric vector with 'false' stutters to replace.
 #' @param byVal numeric vector with correct stutters.
 #' @param debug logical indicating printing debug information.
@@ -115,14 +125,16 @@ calculateStutter <- function(data, ref, back=2, forward=1, interference=0,
     stop("'data' must be in 'slim' format",
          call. = TRUE)
   }
+  
+  # Prepare -------------------------------------------------------------------
 
   # Check data type.
   if(!is.character(data$Allele)){
-    warning("'Allele' must be character. 'data$Allele' converted")
+    message("'Allele' must be character. 'data' converted!")
     data$Allele <- as.character(data$Allele)
   }
   if(!is.numeric(data$Height)){
-    warning("'Height' must be numeric. 'data$Height' converted")
+    message("'Height' must be numeric. 'data' converted!")
     data$Height <- suppressWarnings(as.numeric(data$Height))
   }
   
